# generated by datamodel-codegen:
#   filename:  get_data.json

from __future__ import annotations

from pydantic import BaseModel


class GetData(BaseModel):
    """
    Get Data
    """

    modules: list



# generated by datamodel-codegen:
#   filename:  media_play.json

from __future__ import annotations

from typing import Optional

from pydantic import BaseModel


class MediaPlay(BaseModel):
    """
    Media Play
    """

    album: Optional[str] = None
    artist: Optional[str] = None
    autoplay: Optional[bool] = False
    cover: Optional[str] = None
    title: Optional[str] = None
    url: str
    volume: Optional[float] = 40



# generated by datamodel-codegen:
#   filename:  update_setting.json

from __future__ import annotations

from typing import Any

from pydantic import BaseModel


class UpdateSetting(BaseModel):
    """
    Update Setting
    """

    setting: str
    value: Any



"""
Provides systembridgeconnector version information.
"""

# This file is auto-generated! Do not edit!
# Use `python -m incremental.update systembridgeconnector` to change this file.

from incremental import Version

__version__ = Version("systembridgeconnector", 3, 4, 4)
__all__ = ["__version__"]



# generated by datamodel-codegen:
#   filename:  update.json

from __future__ import annotations

from pydantic import BaseModel


class Update(BaseModel):
    """
    Version
    """

    version: str



# generated by datamodel-codegen:
#   filename:  keyboard_text.json

from __future__ import annotations

from pydantic import BaseModel


class KeyboardText(BaseModel):
    """
    Keyboard Text
    """

    text: str



# generated by datamodel-codegen:
#   filename:  memory.json

from __future__ import annotations

from typing import Optional

from pydantic import BaseModel, Extra, Field


class LastUpdated(BaseModel):
    """
    Last updated
    """

    class Config:
        extra = Extra.allow

    swap_total: float
    swap_used: float
    swap_free: float
    swap_percent: float
    swap_sin: float
    swap_sout: float
    virtual_total: float
    virtual_available: float
    virtual_percent: float
    virtual_used: float
    virtual_free: float


class Memory(BaseModel):
    """
    Memory
    """

    class Config:
        extra = Extra.allow

    id: Optional[str] = Field(None, description="Event ID")
    swap_total: int
    swap_used: int
    swap_free: float
    swap_percent: float
    swap_sin: int
    swap_sout: int
    virtual_total: int
    virtual_available: int
    virtual_percent: float
    virtual_used: int
    virtual_free: int
    last_updated: LastUpdated = Field(..., description="Last updated")



"""System Bridge Connector: Exceptions"""


class AuthenticationException(BaseException):
    """Raise this when there is an authentication issue."""


class ConnectionClosedException(BaseException):
    """Raise this when connection is closed."""


class ConnectionErrorException(BaseException):
    """Raise this when error connecting."""


class BadMessageException(BaseException):
    """Raise this when a bad message is sent."""



# generated by datamodel-codegen:
#   filename:  network.json

from __future__ import annotations

from typing import Optional

from pydantic import BaseModel, Extra, Field


class LastUpdated(BaseModel):
    """
    Last updated
    """

    class Config:
        extra = Extra.allow

    io_counters_bytes_sent: float
    io_counters_bytes_recv: float
    io_counters_packets_sent: float
    io_counters_packets_recv: float
    io_counters_errin: float
    io_counters_errout: float
    io_counters_dropin: float
    io_counters_dropout: float


class Network(BaseModel):
    """
    Network
    """

    class Config:
        extra = Extra.allow

    id: Optional[str] = Field(None, description="Event ID")
    io_counters_bytes_sent: int
    io_counters_bytes_recv: int
    io_counters_packets_sent: int
    io_counters_packets_recv: int
    io_counters_errin: int
    io_counters_errout: int
    io_counters_dropin: int
    io_counters_dropout: int
    last_updated: LastUpdated = Field(..., description="Last updated")



# Data

from __future__ import annotations

from pydantic import BaseModel, Field

from systembridgeconnector.models.battery import Battery
from systembridgeconnector.models.bridge import Bridge
from systembridgeconnector.models.cpu import Cpu
from systembridgeconnector.models.disk import Disk
from systembridgeconnector.models.display import Display
from systembridgeconnector.models.gpu import Gpu
from systembridgeconnector.models.memory import Memory
from systembridgeconnector.models.network import Network
from systembridgeconnector.models.sensors import Sensors
from systembridgeconnector.models.system import System


class Data(BaseModel):
    """Data"""

    battery: Battery = Field(..., alias="battery")
    bridge: Bridge = Field(..., alias="bridge")
    cpu: Cpu = Field(..., alias="cpu")
    disk: Disk = Field(..., alias="disk")
    display: Display = Field(..., alias="display")
    gpu: Gpu = Field(..., alias="gpu")
    memory: Memory = Field(..., alias="memory")
    network: Network = Field(..., alias="network")
    sensors: Sensors = Field(..., alias="sensors")
    system: System = Field(..., alias="system")



# generated by datamodel-codegen:
#   filename:  media_get_file.json

from __future__ import annotations

from pydantic import BaseModel


class MediaGetFile(BaseModel):
    """
    Get File
    """

    base: str
    path: str



# generated by datamodel-codegen:
#   filename:  response.json

from __future__ import annotations

from typing import Any, Optional

from pydantic import BaseModel, Extra, Field


class Response(BaseModel):
    """
    Response
    """

    class Config:
        extra = Extra.allow

    id: Optional[str] = Field(None, description="Message ID")
    type: str = Field(..., description="Type")
    subtype: Optional[str] = Field(None, description="Subtype")
    message: Optional[str] = Field(None, description="Message")
    module: Optional[str] = Field(None, description="Module")
    data: Optional[Any] = Field(None, description="Data")



# generated by datamodel-codegen:
#   filename:  register_data_listener.json

from __future__ import annotations

from pydantic import BaseModel


class RegisterDataListener(BaseModel):
    """
    Register Data Listener
    """

    modules: list
